@@ -7,8 +7,8 @@
  *       for the code
  * 
  * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  * 
  * This software is distributed in the hope that it will be useful, but
@@ -106,7 +106,6 @@ create_hildon_actor(Actor *actor, AWallpaperPlugin *desktop_plugin)
                                              actor->width, 
                                              actor->height, 
                                              NULL);
-  /* fprintf(stderr, "create_hildon_actor %s %s\n", actor->name, str); */
   if (str)
       g_free(str);
   if (pixbuf){
@@ -206,8 +205,9 @@ init_object(AWallpaperPlugin *desktop_plugin,
     actor->func_change = (gpointer)pfunc_change; 
     actor->func_probability = (gpointer)pfunc_probability;
     actor->child = child;
-    if (load_image)
+    if (load_image){
         create_hildon_actor(actor, desktop_plugin);
+    }
     else 
          actor->widget = NULL;
     actor->time_start_animation = 0;
@@ -268,6 +268,7 @@ set_actor_visible(Actor *actor, gboolean visible)
 void
 set_actor_position(Actor *actor, gint x, gint y, gint z, AWallpaperPlugin *desktop_plugin)
 {
+    //fprintf(stderr, "set actor position %d, %d, %d\n", x, y, z);
     hildon_animation_actor_set_position_full(HILDON_ANIMATION_ACTOR (actor->widget), 
                                              x-desktop_plugin->priv->xapplet, 
                                              y-desktop_plugin->priv->yapplet, 
